package nand.apps.chat.model.user

import nand.apps.chat.BuildConfig.APP_NAME
import nand.apps.chat.BuildConfig.APP_VERSION_MAJOR
import nand.apps.chat.BuildConfig.APP_VERSION_MINOR
import nand.apps.chat.BuildConfig.APP_VERSION_PATCH
import nand.apps.chat.model.net.packet.ClientVersionPacketData

data class ChatClientVersion(
    val name: String,
    val major: Int,
    val minor: Int,
    val patch: Int,
) {

    val numberString = "v$major.$minor.$patch"
    
    fun toPacketData() = ClientVersionPacketData(
        name = name,
        major = major,
        minor = minor,
        patch = patch,
    )

    operator fun compareTo(other: ChatClientVersion): Int {
        val majorComp = major.compareTo(other.major)
        val minorComp = minor.compareTo(other.minor)
        val patchComp = patch.compareTo(other.patch)
        return when {
            majorComp != 0 -> majorComp
            minorComp != 0 -> minorComp
            else -> patchComp
        }
    }

    override fun toString() = "$name $numberString"
    
    companion object {
        
        private val DEFAULT = ChatClientVersion(
            name = APP_NAME,
            major = APP_VERSION_MAJOR,
            minor = APP_VERSION_MINOR,
            patch = APP_VERSION_PATCH,
        )
        
        operator fun invoke() = DEFAULT
    }
}