package nand.apps.chat.ui.file

import androidx.compose.foundation.text.BasicText
import androidx.compose.runtime.*
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.*
import androidx.compose.ui.util.fastForEachIndexed
import nand.apps.chat.platform.ChatPlatform
import nand.apps.chat.platform.getPlatform
import nand.apps.chat.ui.theme.ChatThemeScope
import okio.Path.Companion.DIRECTORY_SEPARATOR

@Composable
fun ChatFileDirectoryRow(
    directory: String,
    textStyle: TextStyle,
    onClick: (String) -> Unit,
    modifier: Modifier = Modifier,
) {
    val interactionListener = remember {
        LinkInteractionListener { link ->
            (link as? LinkAnnotation.Clickable)?.let { onClick(it.tag) }
        }
    }
    val text = ChatThemeScope {
        remember(directory) {
            val parts = directory.split(DIRECTORY_SEPARATOR).filter { it.isNotEmpty() }
            buildAnnotatedString {
                val pathBuilder = StringBuilder(
                    if (getPlatform() != ChatPlatform.WINDOWS) DIRECTORY_SEPARATOR else ""
                )
                pushStyle(SpanStyle(color = colors.onBackground))
                parts.fastForEachIndexed { index, part ->
                    pathBuilder.append(part)
                    pathBuilder.append(DIRECTORY_SEPARATOR)
                    val fullPath = pathBuilder.toString()
                    pushLink(
                        LinkAnnotation.Clickable(
                            tag = fullPath,
                            linkInteractionListener = interactionListener,
                        )
                    )
                    if (index > 0) append(' ')
                    if (fullPath == directory) {
                        withStyle(SpanStyle(color = colors.onSurface)) {
                            append(part)
                        }
                    } else {
                        append(part)
                    }
                    append(' ')
                    pop()
                    if (index < parts.lastIndex) append('»')
                }
            }
        }
    }
    BasicText(
        text = text,
        style = textStyle,
        modifier = modifier,
    )
}