package nand.apps.chat.ui.settings.dialog

import androidx.compose.foundation.layout.*
import androidx.compose.runtime.*
import androidx.compose.runtime.saveable.rememberSaveable
import nand.apps.chat.model.settings.notifications.NotificationSoundType
import nand.apps.chat.ui.dialog.SimpleDialog
import nand.apps.chat.ui.settings.SettingsViewModel
import nand.apps.chat.ui.text.SimpleTextRadioButton
import nand.apps.chat.ui.theme.ChatTheme
import org.jetbrains.compose.resources.stringResource
import seers.composeapp.generated.resources.*

@Composable
fun SoundTypeDialog(
    viewModel: SettingsViewModel,
    onConfirm: () -> Unit,
) {
    val settings = viewModel.settings.notificationSettings.soundSettings
    var soundType by rememberSaveable(settings) { mutableStateOf(settings.soundType) }
    SimpleDialog(
        title = Res.string.settings_notifications_sound_type_title,
        titleStyle = ChatTheme.typography.body1,
        onConfirm = {
            viewModel.update(settings.copy(soundType = soundType))
            onConfirm()
        },
        onCancel = onConfirm,
    ) {
        Column {
            SimpleTextRadioButton(
                text = stringResource(Res.string.settings_notifications_sound_type_default),
                selected = soundType == NotificationSoundType.NEW_MESSAGE,
                onClick = { soundType = NotificationSoundType.NEW_MESSAGE },
            )
            SimpleTextRadioButton(
                text = stringResource(Res.string.settings_notifications_sound_type_alt),
                selected = soundType == NotificationSoundType.NEW_MESSAGE_ALT,
                onClick = { soundType = NotificationSoundType.NEW_MESSAGE_ALT },
            )
        }
    }
}