package nand.apps.chat.ui.settings.net

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.outlined.*
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import nand.apps.chat.engine.ChatEngine
import nand.apps.chat.engine.tox.ToxChatEngine
import nand.apps.chat.ui.provider.LocalNavController
import nand.apps.chat.ui.settings.SettingsColumn
import nand.apps.chat.ui.settings.SettingsViewModel
import nand.apps.chat.ui.settings.ToxNodeSettingsRoute
import nand.apps.chat.ui.settings.dialog.NetworkProxySettingDialog
import nand.apps.chat.ui.settings.row.SettingsCheckboxRow
import nand.apps.chat.ui.settings.row.SettingsDialogRow
import nand.apps.chat.ui.settings.row.SettingsRow
import org.koin.compose.getKoin
import seers.composeapp.generated.resources.*

@Composable
fun NetworkSettingsScreen(
    viewModel: SettingsViewModel,
    modifier: Modifier = Modifier,
) = SettingsColumn(
    title = Res.string.settings_network_title,
    modifier = modifier,
) {
    val state = viewModel.settings.networkSettings
    val chatEngine: ChatEngine by getKoin().inject()
    val navController = LocalNavController.current
    SettingsCheckboxRow(
        title = Res.string.settings_network_udp_enabled_title,
        description = Res.string.settings_network_udp_enabled_desc,
        icon = Icons.Outlined.LeakAdd,
        isChecked = state.isUdpEnabled,
        onCheckedChange = { checked ->
            viewModel.update(state.copy(isUdpEnabled = checked))
        }
    )
    SettingsCheckboxRow(
        title = Res.string.settings_network_ipv6_enabled_title,
        description = Res.string.settings_network_ipv6_enabled_desc,
        icon = Icons.Outlined.Domain,
        isChecked = state.isIPv6Enabled,
        onCheckedChange = { checked ->
            viewModel.update(state.copy(isIPv6Enabled = checked))
        }
    )
    SettingsCheckboxRow(
        title = Res.string.settings_network_lan_enabled_title,
        description = Res.string.settings_network_lan_enabled_desc,
        icon = Icons.Outlined.Lan,
        isChecked = state.isLanEnabled,
        onCheckedChange = { checked ->
            viewModel.update(state.copy(isLanEnabled = checked))
        }
    )
    SettingsDialogRow(
        title = Res.string.settings_network_proxy_title,
        description = Res.string.settings_network_proxy_desc,
        icon = Icons.Outlined.VpnLock,
    ) { onConfirm ->
        NetworkProxySettingDialog(
            onUpdateProxy = { viewModel.update(state.copy(proxy = it)) },
            onDismiss = onConfirm,
        )
    }
    if (chatEngine is ToxChatEngine) {
        SettingsRow(
            title = Res.string.settings_network_tox_nodes_title,
            description = Res.string.settings_network_tox_nodes_desc,
            icon = Icons.Outlined.Hub,
            onClick = { navController.navigate(ToxNodeSettingsRoute) },
        )
    }
}