package nand.apps.chat.ui.settings.notifications

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.outlined.*
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import nand.apps.chat.platform.getPlatform
import nand.apps.chat.ui.settings.SettingsColumn
import nand.apps.chat.ui.settings.SettingsViewModel
import nand.apps.chat.ui.settings.dialog.SoundTypeDialog
import nand.apps.chat.ui.settings.row.ChatWidgetPlacementRow
import nand.apps.chat.ui.settings.row.SettingsCheckboxRow
import nand.apps.chat.ui.settings.row.SettingsDialogRow
import nand.apps.chat.ui.settings.row.SettingsSeparator
import seers.composeapp.generated.resources.*

@Composable
fun NotificationSettingsScreen(
    viewModel: SettingsViewModel,
    modifier: Modifier = Modifier,
) = SettingsColumn(
    title = Res.string.settings_notifications_title,
    modifier = modifier,
) {
    val state = viewModel.settings.notificationSettings
    SettingsCheckboxRow(
        title = Res.string.settings_notifications_enable_messages_title,
        description = Res.string.settings_notifications_enable_messages_desc,
        icon = Icons.Outlined.Feedback,
        isChecked = state.isMessageNotificationsEnabled,
        onCheckedChange = { checked ->
            viewModel.update(state.copy(isMessageNotificationsEnabled = checked))
        }
    )
    SettingsCheckboxRow(
        title = Res.string.settings_notifications_enable_calls_title,
        description = Res.string.settings_notifications_enable_calls_desc,
        icon = Icons.Outlined.PermPhoneMsg,
        isChecked = state.isCallNotificationsEnabled,
        onCheckedChange = { checked ->
            viewModel.update(state.copy(isCallNotificationsEnabled = checked))
        }
    )
    if (getPlatform().isDesktop) {
        val widgetState = state.widgetSettings
        val trayState = state.traySettings
        val soundState = state.soundSettings
        SettingsSeparator(
            text = Res.string.settings_notifications_sound_section,
        )
        SettingsCheckboxRow(
            title = Res.string.settings_notifications_sound_notification_title,
            description = Res.string.settings_notifications_sound_notification_desc,
            icon = Icons.Outlined.NotificationsActive,
            isChecked = soundState.isEnabled,
            isEnabled = state.isMessageNotificationsEnabled || state.isCallNotificationsEnabled,
            onCheckedChange = { checked ->
                viewModel.update(soundState.copy(isEnabled = checked))
            }
        )
        SettingsDialogRow(
            title = Res.string.settings_notifications_sound_type_title,
            description = Res.string.settings_notifications_sound_type_desc,
            icon = Icons.Outlined.MusicNote,
            isEnabled = soundState.isEnabled,
            content = { onConfirm ->
                SoundTypeDialog(
                    viewModel = viewModel,
                    onConfirm = onConfirm,
                )
            }
        )
        SettingsCheckboxRow(
            title = Res.string.settings_notifications_sound_new_message_title,
            description = Res.string.settings_notifications_sound_new_message_desc,
            icon = Icons.Outlined.SurroundSound,
            isChecked = soundState.isNewMessageTriggerEnabled,
            isEnabled = soundState.isEnabled,
            onCheckedChange = { checked ->
                viewModel.update(soundState.copy(isNewMessageTriggerEnabled = checked))
            }
        )
        SettingsSeparator(
            text = Res.string.settings_notifications_widget_section,
        )
        SettingsCheckboxRow(
            title = Res.string.settings_notifications_enable_widget_title,
            description = Res.string.settings_notifications_enable_widget_desc,
            icon = Icons.Outlined.MarkChatUnread,
            isChecked = widgetState.isEnabled,
            onCheckedChange = { checked ->
                viewModel.update(widgetState.copy(isEnabled = checked))
            }
        )
        ChatWidgetPlacementRow(
            viewModel = viewModel,
            isEnabled = widgetState.isEnabled,
        )
        SettingsCheckboxRow(
            title = Res.string.settings_notifications_widget_flash_title,
            description = Res.string.settings_notifications_widget_flash_desc,
            icon = Icons.Outlined.Highlight,
            isChecked = widgetState.isFlashEnabled,
            isEnabled = widgetState.isEnabled,
            onCheckedChange = { checked ->
                viewModel.update(widgetState.copy(isFlashEnabled = checked))
            }
        )
        SettingsCheckboxRow(
            title = Res.string.settings_notifications_widget_group_unread_enabled_title,
            description = Res.string.settings_notifications_widget_group_unread_enabled_desc,
            icon = Icons.Outlined.Group,
            isChecked = widgetState.isGroupUnreadEnabled,
            isEnabled = widgetState.isEnabled,
            onCheckedChange = { checked ->
                viewModel.update(widgetState.copy(isGroupUnreadEnabled = checked))
            }
        )
        SettingsCheckboxRow(
            title = Res.string.settings_notifications_widget_group_unread_number_title,
            description = Res.string.settings_notifications_widget_group_unread_number_desc,
            icon = Icons.Outlined.Emergency,
            isChecked = widgetState.isGroupUnreadNumberShown,
            isEnabled = widgetState.isEnabled && widgetState.isGroupUnreadEnabled,
            onCheckedChange = { checked ->
                viewModel.update(widgetState.copy(isGroupUnreadNumberShown = checked))
            }
        )
        SettingsSeparator(
            text = Res.string.settings_notifications_tray_section,
        )
        SettingsCheckboxRow(
            title = Res.string.settings_notifications_enable_tray_icon_title,
            description = Res.string.settings_notifications_enable_tray_icon_desc,
            icon = Icons.Outlined.Apps,
            isChecked = trayState.isEnabled,
            onCheckedChange = { checked ->
                viewModel.update(trayState.copy(isEnabled = checked))
            }
        )
        SettingsCheckboxRow(
            title = Res.string.settings_notifications_tray_flash_title,
            description = Res.string.settings_notifications_tray_flash_desc,
            icon = Icons.Outlined.Highlight,
            isChecked = trayState.isFlashEnabled,
            onCheckedChange = { checked ->
                viewModel.update(trayState.copy(isFlashEnabled = checked))
            }
        )
        SettingsCheckboxRow(
            title = Res.string.settings_notifications_tray_minimize_title,
            description = Res.string.settings_notifications_tray_minimize_desc,
            icon = Icons.Outlined.Minimize,
            isChecked = trayState.isMinimizeEnabled,
            onCheckedChange = { checked ->
                viewModel.update(trayState.copy(isMinimizeEnabled = checked))
            }
        )
    }
}