package nand.apps.chat.ui.snackbar

import androidx.compose.material.SnackbarHostState
import androidx.compose.runtime.*
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.ui.Modifier
import nand.apps.chat.model.event.*
import nand.apps.chat.ui.provider.LocalEventHandler
import nand.apps.chat.ui.theme.ChatTheme

@Composable
fun GlobalSnackbarHost(
    modifier: Modifier = Modifier,
) {
    val eventHandler = LocalEventHandler.current
    var isError by rememberSaveable { mutableStateOf(false) }
    val errorSnackbarState = remember { SnackbarHostState() }
    val successSnackbarState = remember { SnackbarHostState() }
    LaunchedEffect(Unit) {
        eventHandler.onEvent.collect { event ->
            when (event) {
                is ErrorSnackbarEvent -> {
                    isError = true
                    errorSnackbarState.showSnackbar(event.message)
                }
                is SuccessSnackbarEvent -> {
                    isError = false
                    successSnackbarState.showSnackbar(event.message)
                }
                else -> Unit
            }
        }
    }
    if (isError) {
        SimpleSnackbarHost(
            state = errorSnackbarState,
            backgroundColor = ChatTheme.colors.error,
            modifier = modifier,
        )
    } else {
        SimpleSnackbarHost(
            state = successSnackbarState,
            backgroundColor = ChatTheme.colors.secondary,
            modifier = modifier,
        )
    }
}