package nand.apps.chat.ui.text

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.padding
import androidx.compose.material.RadioButton
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import nand.apps.chat.ui.modifier.onClick
import nand.apps.chat.ui.theme.ChatTheme

@Composable
fun SimpleTextRadioButton(
    text: String,
    selected: Boolean,
    onClick: () -> Unit,
    modifier: Modifier = Modifier,
    isEnabled: Boolean = true,
    textColor: Color = ChatTheme.colors.onSurface,
    textStyle: TextStyle = ChatTheme.typography.body2,
    subText: String? = null,
    subTextColor: Color = ChatTheme.colors.onBackground2,
    subTextStyle: TextStyle = ChatTheme.typography.caption,
) = Row(
    verticalAlignment = Alignment.CenterVertically,
    modifier = modifier.onClick(onClick = onClick),
) {
    RadioButton(
        selected = selected,
        onClick = onClick,
        enabled = isEnabled,
    )
    Column(
        modifier = Modifier.padding(end = ChatTheme.dimens.spacingMedium),
    ) {
        TextLine(
            text = text,
            style = textStyle,
            color = textColor,
        )
        subText?.let {
            TextLine(
                text = subText,
                style = subTextStyle,
                color = subTextColor,
            )
        }
    }
}