package nand.apps.chat.text.markdown

import androidx.compose.ui.text.SpanStyle
import androidx.compose.ui.text.buildAnnotatedString
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontStyle
import androidx.compose.ui.text.font.FontWeight
import nand.apps.chat.text.MARKDOWN_STOP_TAG
import nand.apps.chat.text.assertEquals
import nand.apps.chat.text.buildMarkdownText
import kotlin.test.Test

class CodeTextTests {
    
    @Test
    fun `Full code string`() = assertEquals(
        expected = buildAnnotatedString {
            append("This is a line of code")
            addStyle(SpanStyle(fontFamily = FontFamily.Monospace), 0, 22)
            addStringAnnotation(MARKDOWN_STOP_TAG, "`", 0, 22)
        },
        actual = buildMarkdownText("`This is a line of code`"),
    )

    @Test
    fun `Partial code string`() = assertEquals(
        expected = buildAnnotatedString {
            append("This is a function_name() see")
            addStyle(SpanStyle(fontFamily = FontFamily.Monospace), 10, 25)
            addStringAnnotation(MARKDOWN_STOP_TAG, "`", 10, 25)
        },
        actual = buildMarkdownText("This is a `function_name()` see"),
    )

    @Test
    fun `Code string containing unprocessed markdown`() = assertEquals(
        expected = buildAnnotatedString {
            append("This is a function_that_does_thing(**bla**) with no markdown")
            addStyle(SpanStyle(fontWeight = FontWeight.Bold), 52, 60)
            addStyle(SpanStyle(fontFamily = FontFamily.Monospace), 10, 43)
            addStringAnnotation(MARKDOWN_STOP_TAG, "`", 10, 43)
        },
        actual = buildMarkdownText("This is a `function_that_does_thing(**bla**)` with no **markdown**"),
    )
}