package nand.apps.chat.ui.notification

import androidx.compose.foundation.layout.*
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.NonRestartableComposable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.font.FontWeight
import nand.apps.chat.BuildConfig.APP_NAME
import nand.apps.chat.model.event.AppUpdateDialogEvent
import nand.apps.chat.model.event.RequestAppFocusEvent
import nand.apps.chat.model.notification.AppUpdateNotification
import nand.apps.chat.ui.button.SimpleTextButton
import nand.apps.chat.ui.provider.LocalEventHandler
import nand.apps.chat.ui.theme.ChatTheme
import org.jetbrains.compose.resources.stringResource
import seers.composeapp.generated.resources.*

@Composable
@NonRestartableComposable
fun AppUpdateNotificationRenderer(
    notification: AppUpdateNotification,
) = with(notification) {
    val eventHandler = LocalEventHandler.current
    Box(
        modifier = Modifier
            .fillMaxSize()
            .padding(end = ChatTheme.dimens.iconMedium),
    ) {
        Text(
            text = stringResource(
                Res.string.app_updater_new_version_available,
                APP_NAME,
                release.version.numberString,
            ),
            color = ChatTheme.colors.onSurface,
            fontWeight = FontWeight.Bold,
            style = ChatTheme.typography.body1,
            modifier = Modifier.align(Alignment.TopStart),
        )
        SimpleTextButton(
            text = stringResource(Res.string.download),
            onClick = {
                eventHandler += AppUpdateDialogEvent(notification.release)
                eventHandler += RequestAppFocusEvent()
            },
            modifier = Modifier.align(Alignment.BottomEnd),
        )
    }
}