package nand.apps.chat.ui.window

import androidx.compose.runtime.Composable
import androidx.compose.ui.graphics.painter.Painter
import androidx.compose.ui.window.ApplicationScope
import androidx.compose.ui.window.MenuScope
import androidx.compose.ui.window.Tray
import androidx.compose.ui.window.rememberTrayState
import nand.apps.chat.BuildConfig.APP_NAME
import nand.apps.chat.model.event.RequestAppFocusEvent
import nand.apps.chat.model.event.SetSelfStatusEvent
import nand.apps.chat.model.user.UserStatus
import nand.apps.chat.repo.SelfProfileRepo
import nand.apps.chat.ui.provider.LocalEventHandler
import nand.apps.chat.ui.provider.LocalLoginState
import nand.apps.chat.ui.provider.LocalSettingsProvider
import org.jetbrains.compose.resources.StringResource
import org.jetbrains.compose.resources.stringResource
import org.koin.compose.getKoin
import seers.composeapp.generated.resources.*

@Composable
fun ApplicationScope.ChatSystemTrayIcon(
    windowIcon: Painter,
    onClose: () -> Unit,
) {
    val eventHandler = LocalEventHandler.current
    val settings = LocalSettingsProvider.current.notificationSettings.traySettings
    val isLoggedIn = LocalLoginState.current

    if (!settings.isEnabled) return

    val state = rememberTrayState()
    Tray(
        icon = windowIcon,
        state = state,
        tooltip = APP_NAME,
        menu = {
            if (isLoggedIn) {
                StatusMenuItem(
                    status = UserStatus.DEFAULT,
                    label = Res.string.status_online,
                )
                StatusMenuItem(
                    status = UserStatus.AWAY,
                    label = Res.string.status_away,
                )
                StatusMenuItem(
                    status = UserStatus.BUSY,
                    label = Res.string.status_busy,
                )
            }
            Item(
                text = stringResource(Res.string.close),
                onClick = onClose,
            )
        },
        onAction = {
            eventHandler += RequestAppFocusEvent(
                toggle = true,
                isTrayIconEvent = true,
            )
        },
    )
}

@Composable
private fun MenuScope.StatusMenuItem(
    status: UserStatus,
    label: StringResource,
) {
    val selfProfileRepo: SelfProfileRepo by getKoin().inject()
    val eventHandler = LocalEventHandler.current
    Item(
        text = stringResource(label) + when {
            selfProfileRepo.self.status == status -> " ✓"
            else -> ""
        },
        onClick = { eventHandler += SetSelfStatusEvent(status) },
    )
}